@@ -1,11 +1,9 @@
 transformHMPtoHMPTree <-
 function(data){
-if(missing(data)){
+if(missing(data))
 stop("A valid data set is required.")
-}
 
 data <- as.data.frame(t(data))
-data <- cbind(taxa=rownames(data), data)
 
 return(data)
 }
